# Changelog

## Not released yet
## Updated


## 0.2.1 (2024-11-01)
## Updated
- (roy) 透過 model 前綴字串來判斷是否為 TAIDE 開源模型，舉例：taide/openai/Llama3-TAIDE-LX-70B-Chat
## Supported models
- "taide/openai/Llama-3.1-405B-Instruct-FP8",
- "taide/openai/Llama-3.1-70B",
- "taide/openai/Llama-3.1-Nemotron-70B-Instruct",
- "taide/openai/Llama3-TAIDE-LX-70B-Chat",
- "taide/openai/TAIDE-LX-70B-Chat"


## 0.1.0 (2024-10-31)
## Updated
- (roy) 安裝套件：
pip install botrun_litellm
